You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tapestry.apache.org by hl...@apache.org on 2008/05/20 20:52:29 UTC

svn commit: r658390 [28/32] - in /tapestry/tapestry5/branches/hlship-20080520: ./ quickstart/src/main/resources/META-INF/ quickstart/src/main/resources/archetype-resources/src/main/java/pages/ quickstart/src/main/resources/archetype-resources/src/main/...

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PipelineBuilder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PipelineBuilder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PipelineBuilder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PipelineBuilder.java Tue May 20 11:51:35 2008
@@ -12,59 +12,57 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
-
-import org.slf4j.Logger;
-
-import java.util.List;
-
-/**
- * Creates a pipeline from a service inteface and an ordered list of filters. Each filter is defined
- * in terms of a filter interface: the filter interface is a variant of the service interface, where
- * each method has an additional parameter that is an instance of the service interface. Typically,
- * this service parameter (often named "delegate") is either the first or the last parameter of each
- * method.
- * <p/>
- * The implementation of a filter method is expected to pass all of its parameters to the service
- * instance passed into it.
- * <p/>
- * The interesting thing is that there may be multiple filters in the pipeline. A fabricated
- * "bridge" object (that implements the service interface) is created to let each filter invoke
- * methods on the next filter down the pipeline. This simplifies the model for creating pipelines,
- * as each filter is coded as if it was directly "in front of" the terminator. In fact, it may be
- * indirectly invoking methods on the next filter in the pipeline via a bridge instance.
- * <p/>
- * The builder is fairly smart about matching up service interface methods to filter interface
- * methods, but keeping it simple is also a good idea.
- */
-public interface PipelineBuilder
-{
-    /**
-     * Creates a pipeline from the filters and a terminator.
-     *
-     * @param <S>              service type
-     * @param <F>              filter type
-     * @param logger           logs any warnings generated when constructing the pipeline
-     * @param serviceInterface
-     * @param filterInterface
-     * @param filters          sorted list of filters
-     * @param terminator       end of the pipeline
-     * @return an object that encapsulates the filters and the terminator
-     */
-    <S, F> S build(Logger logger, Class<S> serviceInterface, Class<F> filterInterface, List<F> filters, S terminator);
-
-    /**
-     * Creates a pipeline from just the filters. A
-     * {@link DefaultImplementationBuilder default implementation} is created as the terminator.
-     *
-     * @param <S>
-     * @param <F>
-     * @param logger
-     * @param serviceInterface
-     * @param filterInterface
-     * @param filters
-     * @return
-     */
-    <S, F> S build(Logger logger, Class<S> serviceInterface, Class<F> filterInterface, List<F> filters);
-
-}
\ No newline at end of file
+package org.apache.tapestry5.ioc.services;
+
+import org.slf4j.Logger;
+
+import java.util.List;
+
+/**
+ * Creates a pipeline from a service inteface and an ordered list of filters. Each filter is defined in terms of a
+ * filter interface: the filter interface is a variant of the service interface, where each method has an additional
+ * parameter that is an instance of the service interface. Typically, this service parameter (often named "delegate") is
+ * either the first or the last parameter of each method.
+ * <p/>
+ * The implementation of a filter method is expected to pass all of its parameters to the service instance passed into
+ * it.
+ * <p/>
+ * The interesting thing is that there may be multiple filters in the pipeline. A fabricated "bridge" object (that
+ * implements the service interface) is created to let each filter invoke methods on the next filter down the pipeline.
+ * This simplifies the model for creating pipelines, as each filter is coded as if it was directly "in front of" the
+ * terminator. In fact, it may be indirectly invoking methods on the next filter in the pipeline via a bridge instance.
+ * <p/>
+ * The builder is fairly smart about matching up service interface methods to filter interface methods, but keeping it
+ * simple is also a good idea.
+ */
+public interface PipelineBuilder
+{
+    /**
+     * Creates a pipeline from the filters and a terminator.
+     *
+     * @param <S>              service type
+     * @param <F>              filter type
+     * @param logger           logs any warnings generated when constructing the pipeline
+     * @param serviceInterface
+     * @param filterInterface
+     * @param filters          sorted list of filters
+     * @param terminator       end of the pipeline
+     * @return an object that encapsulates the filters and the terminator
+     */
+    <S, F> S build(Logger logger, Class<S> serviceInterface, Class<F> filterInterface, List<F> filters, S terminator);
+
+    /**
+     * Creates a pipeline from just the filters. A {@link DefaultImplementationBuilder default implementation} is
+     * created as the terminator.
+     *
+     * @param <S>
+     * @param <F>
+     * @param logger
+     * @param serviceInterface
+     * @param filterInterface
+     * @param filters
+     * @return
+     */
+    <S, F> S build(Logger logger, Class<S> serviceInterface, Class<F> filterInterface, List<F> filters);
+
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PropertyAccess.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PropertyAccess.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PropertyAccess.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PropertyAccess.java Tue May 20 11:51:35 2008
@@ -12,11 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
 /**
- * A wrapper around the JavaBean Introspector that allows more manageable access to JavaBean
- * properties of objects.
+ * A wrapper around the JavaBean Introspector that allows more manageable access to JavaBean properties of objects.
  * <p/>
  * <p/>
  * Only provides access to <em>simple</em> properties.  Indexed properties are ignored.
@@ -40,8 +39,7 @@
     void set(Object instance, String propertyName, Object value);
 
     /**
-     * Returns the adapter for a particular object instance. A convienience over invoking
-     * {@link #getAdapter(Class)}.
+     * Returns the adapter for a particular object instance. A convienience over invoking {@link #getAdapter(Class)}.
      */
     ClassPropertyAdapter getAdapter(Object instance);
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PropertyAdapter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PropertyAdapter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PropertyAdapter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PropertyAdapter.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import org.apache.tapestry.ioc.AnnotationProvider;
+import org.apache.tapestry5.ioc.AnnotationProvider;
 
 import java.lang.reflect.Method;
 
@@ -22,7 +22,7 @@
  * Provides access to a single property within a class. Acts as an {@link AnnotationProvider}; when searching for
  * annotations, the read method (if present) is checked first, followed by the write method.
  *
- * @see org.apache.tapestry.ioc.services.ClassPropertyAdapter
+ * @see org.apache.tapestry5.ioc.services.ClassPropertyAdapter
  */
 public interface PropertyAdapter extends AnnotationProvider
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PropertyShadowBuilder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PropertyShadowBuilder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PropertyShadowBuilder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PropertyShadowBuilder.java Tue May 20 11:51:35 2008
@@ -1,28 +1,26 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.services;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc.services;
 
 /**
- * Creates a "shadow" of a property of an object. The shadow has the same type as the property, and
- * delegates all method invocations to the property. Each method invocation on the shadow
- * re-acquires the value of the property from the underlying object and delegates to the current
- * value of the property.
+ * Creates a "shadow" of a property of an object. The shadow has the same type as the property, and delegates all method
+ * invocations to the property. Each method invocation on the shadow re-acquires the value of the property from the
+ * underlying object and delegates to the current value of the property.
  * <p/>
- * Typically, the object in question is another service, one with the "perthread" service lifecycle.
- * This allows a global singleton to shadow a value that is specific to the current thread (and
- * therefore, the current request).
+ * Typically, the object in question is another service, one with the "perthread" service lifecycle. This allows a
+ * global singleton to shadow a value that is specific to the current thread (and therefore, the current request).
  */
 public interface PropertyShadowBuilder
 {
@@ -30,8 +28,7 @@
      * @param <T>
      * @param source       the object from which a property will be extracted
      * @param propertyName the name of a property of the object, which must be readable
-     * @param propertyType the expected type of the property, the actual property type must be assignable to
-     *                     this type
+     * @param propertyType the expected type of the property, the actual property type must be assignable to this type
      * @return the shadow
      */
     <T> T build(Object source, String propertyName, Class<T> propertyType);

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/RegistryShutdownHub.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/RegistryShutdownHub.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/RegistryShutdownListener.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/RegistryShutdownListener.java Tue May 20 11:51:35 2008
@@ -1,18 +1,18 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.services;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc.services;
 
 import java.util.EventListener;
 
@@ -22,9 +22,9 @@
 public interface RegistryShutdownListener extends EventListener
 {
     /**
-     * Invoked when the registry shuts down, giving services a chance to perform any final
-     * operations. Service implementations should not attempt to invoke methods on other services
-     * (via proxies) as the service proxies may themselves be shutdown.
+     * Invoked when the registry shuts down, giving services a chance to perform any final operations. Service
+     * implementations should not attempt to invoke methods on other services (via proxies) as the service proxies may
+     * themselves be shutdown.
      */
     void registryDidShutdown();
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ServiceActivity.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ServiceActivity.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ServiceActivity.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ServiceActivity.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import org.apache.tapestry.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.def.ServiceDef;
 
 /**
  * Provided by the {@link ServiceActivityScoreboard} to track a single service's state and activity.
@@ -29,8 +29,7 @@
     String getServiceId();
 
     /**
-     * The interface implemented by the service (this may occasionally be a class, for non-proxied
-     * services).
+     * The interface implemented by the service (this may occasionally be a class, for non-proxied services).
      */
     Class getServiceInterface();
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ServiceActivityScoreboard.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ServiceActivityScoreboard.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ServiceLifecycleSource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ServiceLifecycleSource.java Tue May 20 11:51:35 2008
@@ -1,24 +1,24 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.services;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
 
-import org.apache.tapestry.ioc.ServiceLifecycle;
+package org.apache.tapestry5.ioc.services;
+
+import org.apache.tapestry5.ioc.ServiceLifecycle;
 
 /**
- * Provides access to user defined lifecycles (beyond the two built-in lifecycles: "singleton" and
- * "primitive"). The user defined lifecycles are contributed into the service's configuration.
+ * Provides access to user defined lifecycles (beyond the two built-in lifecycles: "singleton" and "primitive"). The
+ * user defined lifecycles are contributed into the service's configuration.
  */
 public interface ServiceLifecycleSource
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/Status.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/Status.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/Status.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/Status.java Tue May 20 11:51:35 2008
@@ -12,13 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import org.apache.tapestry.ioc.Registry;
+import org.apache.tapestry5.ioc.Registry;
 
 /**
- * Used in {@link ServiceActivity} to identify the state of the service in terms of its overall
- * lifecycle.
+ * Used in {@link ServiceActivity} to identify the state of the service in terms of its overall lifecycle.
  */
 public enum Status
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/StrategyBuilder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/StrategyBuilder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/StrategyBuilder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/StrategyBuilder.java Tue May 20 11:51:35 2008
@@ -1,27 +1,27 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.services;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
 
-import org.apache.tapestry.ioc.util.StrategyRegistry;
+package org.apache.tapestry5.ioc.services;
+
+import org.apache.tapestry5.ioc.util.StrategyRegistry;
 
 /**
- * A service implementation builder that operates around a {@link StrategyRegistry}, implementing a
- * version of the Gang of Four Strategy pattern.
+ * A service implementation builder that operates around a {@link StrategyRegistry}, implementing a version of the Gang
+ * of Four Strategy pattern.
  * <p/>
- * The constructed service is configured with a number of adapters (that implement the same service
- * interface). Method invocations on the service are routed to one of the adapters.
+ * The constructed service is configured with a number of adapters (that implement the same service interface). Method
+ * invocations on the service are routed to one of the adapters.
  * <p/>
  * The first parameter of each method is used to select the appropriate adapter.
  * <p/>
@@ -30,9 +30,8 @@
 public interface StrategyBuilder
 {
     /**
-     * Given a number of adapters implementing the service interface, builds a "dispatcher"
-     * implementations that delegates to the one of the adapters. It is an error if any of the
-     * methods takes no parameters.
+     * Given a number of adapters implementing the service interface, builds a "dispatcher" implementations that
+     * delegates to the one of the adapters. It is an error if any of the methods takes no parameters.
      *
      * @param <S>      the service interface type
      * @param registry defines the adapters based on parameter type (of the first parameter)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/SymbolProvider.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/SymbolProvider.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/SymbolProvider.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/SymbolProvider.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
 /**
  * A provider of values for symbols.
@@ -20,8 +20,8 @@
 public interface SymbolProvider
 {
     /**
-     * Returns the value for the symbol, or null if this provider can not provide a value. The value
-     * itself may contain symbols that will be recursively expanded.
+     * Returns the value for the symbol, or null if this provider can not provide a value. The value itself may contain
+     * symbols that will be recursively expanded.
      *
      * @param symbolName
      * @return the value or null

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/SymbolSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/SymbolSource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/SymbolSource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/SymbolSource.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import org.apache.tapestry.ioc.annotation.Value;
+import org.apache.tapestry5.ioc.annotations.Value;
 
 /**
  * Used to manage <em>symbols</em>, configuration properties whose value is evaluated at runtime. Symbols use the Ant

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/TapestryIOCModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/TapestryIOCModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ThreadCleanupListener.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ThreadCleanupListener.java Tue May 20 11:51:35 2008
@@ -1,32 +1,32 @@
-// Copyright 2006, 2008 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.services;
-
-import java.util.EventListener;
-
-/**
- * Listener interface for object that need to know about thread event cleanup.
- * <p/>
- * Note that registration with the {@link org.apache.tapestry.ioc.services.PerthreadManager} is a
- * one-shot affair; it lasts no longer than the next cleanup.
- */
-public interface ThreadCleanupListener extends EventListener
-{
-    /**
-     * Invoked by {@link org.apache.tapestry.ioc.services.PerthreadManager} service when a thread
-     * performs and end-of-request cleanup.
-     */
-    void threadDidCleanup();
-}
\ No newline at end of file
+// Copyright 2006, 2008 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc.services;
+
+import java.util.EventListener;
+
+/**
+ * Listener interface for object that need to know about thread event cleanup.
+ * <p/>
+ * Note that registration with the {@link org.apache.tapestry5.ioc.services.PerthreadManager} is a one-shot affair; it
+ * lasts no longer than the next cleanup.
+ */
+public interface ThreadCleanupListener extends EventListener
+{
+    /**
+     * Invoked by {@link org.apache.tapestry5.ioc.services.PerthreadManager} service when a thread performs and
+     * end-of-request cleanup.
+     */
+    void threadDidCleanup();
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ThreadLocale.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ThreadLocale.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ThreadLocale.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ThreadLocale.java Tue May 20 11:51:35 2008
@@ -12,15 +12,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import org.apache.tapestry.ioc.Registry;
+import org.apache.tapestry5.ioc.Registry;
 
 import java.util.Locale;
 
 /**
- * Stores the locale <em>for the current thread</em>. This value persists until
- * {@link Registry#cleanupThread()} is invoked.
+ * Stores the locale <em>for the current thread</em>. This value persists until {@link Registry#cleanupThread()} is
+ * invoked.
  */
 public interface ThreadLocale
 {
@@ -32,8 +32,8 @@
     void setLocale(Locale locale);
 
     /**
-     * Returns the thread's locale, which will be the JVM's default locale, until
-     * {@link #setLocale(Locale)} is invoked.
+     * Returns the thread's locale, which will be the JVM's default locale, until {@link #setLocale(Locale)} is
+     * invoked.
      *
      * @return the thread's locale
      */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/TypeCoercer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/TypeCoercer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/TypeCoercer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/TypeCoercer.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
 /**
  * Makes use of {@link Coercion}s (via {@link CoercionTuple}s) to convert between an input value (of some specific type)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/test/IOCTestCase.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/test/IOCTestCase.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/test/IOCTestCase.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/test/IOCTestCase.java Tue May 20 11:51:35 2008
@@ -12,15 +12,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.test;
+package org.apache.tapestry5.ioc.test;
 
-import org.apache.tapestry.ioc.*;
-import org.apache.tapestry.ioc.annotation.IntermediateType;
-import org.apache.tapestry.ioc.def.ContributionDef;
-import org.apache.tapestry.ioc.def.DecoratorDef;
-import org.apache.tapestry.ioc.def.ModuleDef;
-import org.apache.tapestry.ioc.def.ServiceDef;
-import org.apache.tapestry.ioc.services.*;
+import org.apache.tapestry5.ioc.*;
+import org.apache.tapestry5.ioc.annotations.IntermediateType;
+import org.apache.tapestry5.ioc.def.ContributionDef;
+import org.apache.tapestry5.ioc.def.DecoratorDef;
+import org.apache.tapestry5.ioc.def.ModuleDef;
+import org.apache.tapestry5.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.services.*;
 import static org.easymock.EasyMock.isA;
 import org.slf4j.Logger;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/test/MockTester.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/test/MockTester.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/test/MockTester.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/test/MockTester.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.test;
+package org.apache.tapestry5.ioc.test;
 
 import org.easymock.EasyMock;
 import org.easymock.IMocksControl;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/test/TestBase.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/test/TestBase.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/test/TestBase.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/test/TestBase.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.test;
+package org.apache.tapestry5.ioc.test;
 
 import org.easymock.EasyMock;
 import org.easymock.IExpectationSetters;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/AbstractMessages.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/AbstractMessages.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/AbstractMessages.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/AbstractMessages.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.util;
+package org.apache.tapestry5.ioc.util;
 
-import org.apache.tapestry.ioc.MessageFormatter;
-import org.apache.tapestry.ioc.Messages;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newCaseInsensitiveMap;
-import org.apache.tapestry.ioc.internal.util.ConcurrentBarrier;
-import org.apache.tapestry.ioc.internal.util.Invokable;
-import org.apache.tapestry.ioc.internal.util.MessageFormatterImpl;
+import org.apache.tapestry5.ioc.MessageFormatter;
+import org.apache.tapestry5.ioc.Messages;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newCaseInsensitiveMap;
+import org.apache.tapestry5.ioc.internal.util.ConcurrentBarrier;
+import org.apache.tapestry5.ioc.internal.util.Invokable;
+import org.apache.tapestry5.ioc.internal.util.MessageFormatterImpl;
 
 import java.util.Locale;
 import java.util.Map;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/BodyBuilder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/BodyBuilder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/CaseInsensitiveMap.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/CaseInsensitiveMap.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.util;
+package org.apache.tapestry5.ioc.util;
 
 import java.io.Serializable;
 import java.util.*;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/ExceptionUtils.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/ExceptionUtils.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/ExceptionUtils.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/ExceptionUtils.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.util;
+package org.apache.tapestry5.ioc.util;
 
 /**
  * Contains static methods useful for manipulating exceptions.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/Stack.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/Stack.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/Stack.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/Stack.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.util;
+package org.apache.tapestry5.ioc.util;
 
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
 
 /**
  * A simple, streamlined implementation of {@link java.util.Stack}. The implementation is <em>not</em> threadsafe.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/StrategyRegistry.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/StrategyRegistry.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/StrategyRegistry.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/StrategyRegistry.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.util;
+package org.apache.tapestry5.ioc.util;
 
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import org.apache.tapestry.ioc.internal.util.InheritanceSearch;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.internal.util.InheritanceSearch;
 
 import java.util.Collection;
 import java.util.List;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/TimeInterval.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/TimeInterval.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/TimeInterval.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/TimeInterval.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.util;
+package org.apache.tapestry5.ioc.util;
 
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
 
 import java.util.Map;
 import java.util.regex.Matcher;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/UtilMessages.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/UtilMessages.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/UtilMessages.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/UtilMessages.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.util;
+package org.apache.tapestry5.ioc.util;
 
-import org.apache.tapestry.ioc.Messages;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.internal.util.MessagesImpl;
+import org.apache.tapestry5.ioc.Messages;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.internal.util.MessagesImpl;
 
 import java.util.Collection;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/resources/org/apache/tapestry5/ioc/internal/IOCStrings.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/resources/org/apache/tapestry5/ioc/internal/IOCStrings.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/resources/org/apache/tapestry5/ioc/internal/IOCStrings.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/resources/org/apache/tapestry5/ioc/internal/IOCStrings.properties Tue May 20 11:51:35 2008
@@ -86,4 +86,4 @@
 autobuild-constructor-error=Error invoking constructor %s: %s
 overlapping-service-proxy-providers=Setting a new service proxy provider when there's already an existing provider. This may indicate that you have multiple IoC Registries.
 unexpected-service-proxy-provider=Unexpected service proxy provider when clearing the provider. This may indicate that you have multiple IoC Registries.
-no-proxy-provider=Service token for service '%s' can not be converted back into a proxy because no proxy provider has been registered. This may indicate that an IoC Registry has not been started yet.
\ No newline at end of file
+no-proxy-provider=Service token for service '%s' can not be converted back into a proxy because no proxy provider has been registered. This may indicate that an IoC Registry has not been started yet.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/resources/org/apache/tapestry5/ioc/util/UtilStrings.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/resources/org/apache/tapestry5/ioc/util/UtilStrings.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/resources/org/apache/tapestry5/ioc/util/UtilStrings.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/resources/org/apache/tapestry5/ioc/util/UtilStrings.properties Tue May 20 11:51:35 2008
@@ -15,4 +15,4 @@
 no-strategy-adapter=No adapter from type %s to type %s is available (registered types are %s).
 stack-is-empty=Stack is empty.
 invalid-time-interval-unit=Unknown time interval unit '%s' (in '%s').  Defined units: %s.
-invalid-time-interval-input=Unexpected string '%s' (in time interval '%s').
\ No newline at end of file
+invalid-time-interval-input=Unexpected string '%s' (in time interval '%s').

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/case.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/case.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/case.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/case.apt Tue May 20 11:51:35 2008
@@ -22,4 +22,4 @@
   Just case is ignored --
   other punctuation, as well as whitespace, must exactly match.
   
-  Under the covers, this is supported by the {{{../apidocs/org/apache/tapestry/ioc/CaseInsensitiveMap.html}CaseInsensitiveMap}} class.
\ No newline at end of file
+  Under the covers, this is supported by the {{{../apidocs/org/apache/tapestry5/ioc/CaseInsensitiveMap.html}CaseInsensitiveMap}} class.
\ No newline at end of file

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/coerce.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/coerce.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/coerce.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/coerce.apt Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
   may also happen inside tapestry-ioc, such as when injecting a value, rather than a service, into a builder method.
   
   Like everything else in Tapestry, type coercions are extensible.  At the root is the
-  {{{../apidocs/org/apache/tapestry/ioc/services/TypeCoercer.html}TypeCoercer}} service. Its configuration consists
+  {{{../apidocs/org/apache/tapestry5/ioc/services/TypeCoercer.html}TypeCoercer}} service. Its configuration consists
   of a number of 
-  {{{../apidocs/org/apache/tapestry/ioc/services/CoercionTuple.html}CoercionTuple}}s.  Each tuple defines how to coerce from one type to another.
+  {{{../apidocs/org/apache/tapestry5/ioc/services/CoercionTuple.html}CoercionTuple}}s.  Each tuple defines how to coerce from one type to another.
   The initial set of coercions is focused primarily on coercions between different numeric types:
   
 [images/type-coercer.png] Default Type Coercions  

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/command.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/command.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/command.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/command.apt Tue May 20 11:51:35 2008
@@ -32,7 +32,7 @@
 
   Because this pattern is used so often inside Tapestry, a built-in service exists
   to create implementations of the pattern as needed.  The
-  {{{../apidocs/org/apache/tapestry/ioc/services/ChainBuilder.html}ChainBuilder}}
+  {{{../apidocs/org/apache/tapestry5/ioc/services/ChainBuilder.html}ChainBuilder}}
   service takes care of all the work:
   
 +----+

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/configuration.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/configuration.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/configuration.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/configuration.apt Tue May 20 11:51:35 2008
@@ -129,7 +129,7 @@
   of the service.  
   
   On the contribution side, a service contribution method sees a 
-  {{{apidocs/org/apache/tapestry/ioc/Configuration.html}Configuration}} object:
+  {{{apidocs/org/apache/tapestry5/ioc/Configuration.html}Configuration}} object:
   
 +------+
   public static void contributeStartup(Configuration<Runnable> configuration)
@@ -188,7 +188,7 @@
   
   For our service contribution methods, we must provide a parameter
   of type 
-  {{{apidocs/org/apache/tapestry/ioc/OrderedConfiguration.html}OrderedConfiguration}}:
+  {{{apidocs/org/apache/tapestry5/ioc/OrderedConfiguration.html}OrderedConfiguration}}:
  
 +------+
   public static void contributeStartup(OrderedConfiguration<Runnable> configuration)
@@ -224,7 +224,7 @@
   The value may not be null.
   
   For mapped configurations where the key type is String, a 
-  {{{apidocs/org/apache/tapestry/ioc/util/CaseInsensitiveMap.html}CaseInsensitiveMap}}
+  {{{apidocs/org/apache/tapestry5/ioc/util/CaseInsensitiveMap.html}CaseInsensitiveMap}}
   will be  automatically used (and passed to the service builder method), to help ensure that {{{case.html}case insensitivity}} 
   is automatic and pervasive.
   
@@ -236,7 +236,7 @@
   other things to be injected.
   
   
-  * {{{apidocs/org/apache/tapestry/ioc/ObjectLocator.html}ObjectLocator}}:  access to other services visible
+  * {{{apidocs/org/apache/tapestry5/ioc/ObjectLocator.html}ObjectLocator}}:  access to other services visible
   to the contributing module
   
   []

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/cookbook/basics.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/cookbook/basics.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/cookbook/basics.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/cookbook/basics.apt Tue May 20 11:51:35 2008
@@ -24,10 +24,10 @@
   The simplest services don't have any special configuration or dependencies.  They are defined as services so that
   they can be shared.
 
-  For example, the {{{../../apidocs/org/apache/tapestry/ioc/services/PropertyAccess.html}PropertyAccess}} service 
+  For example, the {{{../../apidocs/org/apache/tapestry5/ioc/services/PropertyAccess.html}PropertyAccess}} service
   is used in multiple places around the framework to access properties of objects (its a wrapper around
   the Java Beans Introspector and a bit of reflection).  This is defined in the
-  {{{../../apidocs/org/apache/tapestry/ioc/services/TapestryIOCModule.html}TapestryIOCModule}}.
+  {{{../../apidocs/org/apache/tapestry5/ioc/services/TapestryIOCModule.html}TapestryIOCModule}}.
 
   It's useful to share PropertyAccess, because it does a lot of useful caching internally.
 
@@ -43,7 +43,7 @@
   }
 +----+
   
-  This example includes {{{../../apidocs/org/apache/tapestry/ioc/services/ExceptionAnalyzer.html}ExceptionAnalyzer}}, 
+  This example includes {{{../../apidocs/org/apache/tapestry5/ioc/services/ExceptionAnalyzer.html}ExceptionAnalyzer}},
   because it has a dependency on PropertyAccess:
 
 +----+
@@ -83,14 +83,14 @@
   dependency injection occurs on the parameters of the service builder method.
 
   The Tapestry web framework includes the concept of an "asset": a resource that may be inside a web application, or packaged
-  inside a JAR.  Assets are represented as the type {{{../../apidcos/org/apache/tapestry/Asset.html}Asset}}.
+  inside a JAR.  Assets are represented as the type {{{../../apidcos/org/apache/tapestry5/Asset.html}Asset}}.
 
   In fact, there are different implementations of this class: one for context resources (part of the web application), the other
   for classpath resources (packaged inside a JAR).  The Asset instances are created via
   {{{../../apidocs/org/apache/tapesty/services/AssetFactory.html}AssetFactory}} services.
 
   Tapestry defines two such services, in the
-  {{{../../apidocs/org/apache/tapestry/services/TapestryModule.html}TapestryModule}}.
+  {{{../../apidocs/org/apache/tapestry5/services/TapestryModule.html}TapestryModule}}.
 
 +---+
   @Marker(ClasspathProvider.class)
@@ -119,7 +119,7 @@
   What's important is that the services are differentiated not just in terms of their id (which is defined by the name of the method,
   after stripping off "build"), but in terms of their <marker annotation>.
 
-  The {{{../../apidocs/org/apache/tapestry/ioc/annotations/Marker.html}Marker}} annotation provides the discriminator.  When
+  The {{{../../apidocs/org/apache/tapestry5/ioc/annotations/Marker.html}Marker}} annotation provides the discriminator.  When
   the service type is supplemented with the ClasspathProvider annotation, the ClasspathAssetFactory is injected.  When the
   service type is supplemented with the ContextProvider annotation, the ContextAssetFactory is injected.
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/cookbook/patterns.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/cookbook/patterns.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/cookbook/patterns.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/cookbook/patterns.apt Tue May 20 11:51:35 2008
@@ -15,7 +15,7 @@
 Chain of Command Pattern
 
   Let's look at another example, again from the Tapestry code base.  The
-  {{{../../apidocs/org/apache/tapestry/services/InjectionProvider.html}InjectProvider}} interface
+  {{{../../apidocs/org/apache/tapestry5/services/InjectionProvider.html}InjectProvider}} interface
   is used to process the @Inject annotation on the fields of a Tapestry page or component.
   Many different instances are combined together to form a
   {{{../command.html}chain of command}}.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/cookbook/servconf.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/cookbook/servconf.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/cookbook/servconf.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/cookbook/servconf.apt Tue May 20 11:51:35 2008
@@ -24,7 +24,7 @@
   The checksum is derived from the file contents; thus it can't be spoofed from the client unless the client already has the file contents.
 
   This is controlled by the 
-  {{{../../apidocs/org/apache/tapestry/services/ResourceDigestGenerator.html}ResourceDigestGenerator}} service, which uses its
+  {{{../../apidocs/org/apache/tapestry5/services/ResourceDigestGenerator.html}ResourceDigestGenerator}} service, which uses its
   configuration to determine which file extensions require an MD5 digest.
 
 * Contributing to a Service
@@ -41,7 +41,7 @@
 
   This is a <service contribution method>, a method that is invoked to provide values for a configuration.  We'll see how the
   service receives these contributions shortly.  The 
-  {{{../../apidocs/org/apache/tapestry/ioc/Configuration.html}Configuration}} object is how
+  {{{../../apidocs/org/apache/tapestry5/ioc/Configuration.html}Configuration}} object is how
   values are added to the service's configuration. Other parameters to a service configuration method are injected
   much as with a service's constructor, or a service builder method.
 
@@ -102,7 +102,7 @@
   {{{../pipeline.html}Pipeline}}.
 
   Here, the example is the
-  {{{../../apidocs/org/apache/tapestry/services/Dispatcher.html}Dispatcher}} interface; a Dispatcher inside Tapestry
+  {{{../../apidocs/org/apache/tapestry5/services/Dispatcher.html}Dispatcher}} interface; a Dispatcher inside Tapestry
   is roughly equivalent to a servlet, though a touch more active.  It is passed a Request and decides if the URL
   for the Request is something it can handle; if so it will process the request, send a response, and return true.
 
@@ -129,7 +129,7 @@
 }
 +---+
 
-  With an {{{../../apidcos/org/apache/tapestry/ioc/OrderedConfiguration.html}OrderedConfiguration}}, 
+  With an {{{../../apidcos/org/apache/tapestry5/ioc/OrderedConfiguration.html}OrderedConfiguration}},
   each contribution gets a name, which must be unique.  Here the names are RootPath, Asset, PageRender and ComponentAction.
 
   The add() method takes a name, the contributed object for that name, and then zero or more optional constraints.
@@ -139,8 +139,8 @@
   The ordering occurs on the complete set of contributions, from all modules. 
 
   Here, we need a specific order, used to make sure that the Dispatchers don't get confused about which URLs
-  are appropriate ... for example, an asset URL might be /assets/tapestry/tapestry.js.  This looks just like
-  a component action URL (for page "assets/tapestry/tapestry" and component "js"). Given that software is totally lacking
+  are appropriate ... for example, an asset URL might be /assets/tapestry5/tapestry.js.  This looks just like
+  a component action URL (for page "assets/tapestry5/tapestry" and component "js"). Given that software is totally lacking
   in basic common-sense, we instead use careful ordering of the Dipstachers to ensure that AssetDispatcher is checked <before> 
   the ComponentAction dispatcher.
 
@@ -158,7 +158,7 @@
   }
 +----+
 
-  {{{../../apidocs/org/apache/tapestry/ioc/services/ChainBuilder.html}ChainBuilder}} is a service that
+  {{{../../apidocs/org/apache/tapestry5/ioc/services/ChainBuilder.html}ChainBuilder}} is a service that
   <builds other services>.  Here it creates an object of type Dispatcher in terms of the list of Dispatchers.
   This is one of the most common uses of service builder methods ... for when the service implementation
   doesn't exist, but can be constructed at runtime.
@@ -171,7 +171,7 @@
 
   Tapestry IoC's {{{../symbols.html}symbols}} mechanism allows configuration values to be defined and perhaps overridden, then
   provided to services via injection, using
-  the  {{{../../apidocs/org/apache/tapestry/ioc/annotations/Value.html}Value}} annotation.
+  the  {{{../../apidocs/org/apache/tapestry5/ioc/annotations/Value.html}Value}} annotation.
 
   The first step is to contribute values.
 
@@ -186,8 +186,8 @@
     configuration.add("tapestry.scriptaculous", "classpath:${tapestry.scriptaculous.path}");
     configuration.add(
             "tapestry.scriptaculous.path",
-            "org/apache/tapestry/scriptaculous_1_7_1_beta_3");
-    configuration.add("tapestry.jscalendar.path", "org/apache/tapestry/jscalendar-1.0");
+            "org/apache/tapestry5/scriptaculous_1_7_1_beta_3");
+    configuration.add("tapestry.jscalendar.path", "org/apache/tapestry5/jscalendar-1.0");
     configuration.add("tapestry.jscalendar", "classpath:${tapestry.jscalendar.path}");
   }
 +---+

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/decorator.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/decorator.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/decorator.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/decorator.apt Tue May 20 11:51:35 2008
@@ -57,7 +57,7 @@
 +---------------------+
 package org.example.myapp.services;
 
-import org.apache.tapestry.ioc.services.LoggingDecorator;
+import org.apache.tapestry5.ioc.services.LoggingDecorator;
 import org.slf4j.Logger;
 
 public class MyAppModule
@@ -112,7 +112,7 @@
 +---------------------+
 package org.example.myapp.services;
 
-import org.apache.tapestry.ioc.services.LoggingDecorator;
+import org.apache.tapestry5.ioc.services.LoggingDecorator;
 import org.slf4j.Logger;
 
 public class MyAppModule
@@ -131,7 +131,7 @@
 Targetting Multiple Services
 
   By using the
-  {{{../apidocs/org/apache/tapestry/ioc/annotations/Match.html}@Match annnotation}},
+  {{{../apidocs/org/apache/tapestry5/ioc/annotations/Match.html}@Match annnotation}},
   you may identify which services are to be decorated.
   
   The value specified in the Match annotation is one or more patterns. These patterns
@@ -176,7 +176,7 @@
 
    In cases where multiple decorators will apply to a single service, you can control
    the order in which decorators are applied using  an additional annotation:
-   {{{../apidocs/org/apache/tapestry/ioc/annotations/Order.html}@Order}}.
+   {{{../apidocs/org/apache/tapestry5/ioc/annotations/Order.html}@Order}}.
    
    This annotation allows any number of {{{order.html}ordering constraints}}
    to be specified for the decorator, to order it relative to
@@ -214,9 +214,9 @@
   the service (because these interceptors can get chained, we talk about the "delegate" and not the "service").
 
   Each method of the interceptor will take <advice>.  Advice
-  is provided by a {{{../apidocs/org/apache/tapestry/ioc/MethodAdvice.html}MethodAdvice}} instance.
+  is provided by a {{{../apidocs/org/apache/tapestry5/ioc/MethodAdvice.html}MethodAdvice}} instance.
   The sole method, <<<advise()>>>, recieves an
-   {{{../apidocs/org/apache/tapestry/ioc/Invocation.html}Invocation}}.
+   {{{../apidocs/org/apache/tapestry5/ioc/Invocation.html}Invocation}}.
   MethodAdvice gives you a chance to see what the method invocation <is>; you can query
   the name of the method, and the types and values of the parameters.
 
@@ -237,7 +237,7 @@
   query or even replace the return value.
 
   The
-  {{{../apidocs/org/apache/tapestry/ioc/services/AspectDecorator.html}AspectDecorator}} service
+  {{{../apidocs/org/apache/tapestry5/ioc/services/AspectDecorator.html}AspectDecorator}} service
   is how you put your MethodAdvise into action.
 
   By way of an example, we'll show an implementation of the LoggingDecorator service:

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/module.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/module.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/module.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/module.apt Tue May 20 11:51:35 2008
@@ -83,7 +83,7 @@
 +---+
 package org.example.myapp.services;
 
-import org.apache.tapestry.ioc.ServiceBinder;
+import org.apache.tapestry5.ioc.ServiceBinder;
 
 public class MyAppModule
 {
@@ -158,7 +158,7 @@
       
   * {{{http://www.slf4j.org/api/org/slf4j/Logger.html}org.slf4j.Logger}}: logger for the module (derived from the module's class name)
    
-  * {{{../apidocs/org/apache/tapestry/ioc/ObjectLocator.html}ObjectLocator}}:  access to other services
+  * {{{../apidocs/org/apache/tapestry5/ioc/ObjectLocator.html}ObjectLocator}}:  access to other services
   
   []
   
@@ -235,7 +235,7 @@
   or packages).
   
   A better alternative is the 
-  {{{../apidocs/org/apache/tapestry/ioc/annotations/SubModule.html}@SubModule annotation}}.
+  {{{../apidocs/org/apache/tapestry5/ioc/annotations/SubModule.html}@SubModule annotation}}.
   
   The value for this annotation is a list of <additional> classes to be treated as module builder classes,
   exactly as if they were identified in the manifest.  For example:

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/order.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/order.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/order.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/order.apt Tue May 20 11:51:35 2008
@@ -27,7 +27,7 @@
   control what other objects must come before a contribution, or come after.
   
   The constraints are specified using the
-  {{{../apidocs/org/apache/tapestry/ioc/annotations/Order.html}Order}} annotation (for
+  {{{../apidocs/org/apache/tapestry5/ioc/annotations/Order.html}Order}} annotation (for
   service decorator methods), or as variable arguments at the end of the add() method
   for ordered configurations.
   

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/pipeline.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/pipeline.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/pipeline.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/pipeline.apt Tue May 20 11:51:35 2008
@@ -62,7 +62,7 @@
 +-----+  
 
   The
-  {{{../apidocs/org/apache/tapestry/ioc/services/PipelineBuilder.html}PipelineBuilder}}
+  {{{../apidocs/org/apache/tapestry5/ioc/services/PipelineBuilder.html}PipelineBuilder}}
   service is useful for constructing pipelines. The service is often injected
   into a service builder method, along with an ordered configuration of services.
   

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/provider.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/provider.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/provider.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/provider.apt Tue May 20 11:51:35 2008
@@ -4,7 +4,7 @@
 
 Object Providers
 
-  When you don't provide the {{{../apidocs/org/apache/tapestry/ioc/annotations/InjectService.html}InjectService}} annotation
+  When you don't provide the {{{../apidocs/org/apache/tapestry5/ioc/annotations/InjectService.html}InjectService}} annotation
   on a parameter (to a service builder method or constructor), Tapestry will
   resolve the parameter automatically.
   
@@ -12,13 +12,13 @@
   be injected is not necessarily a service; it may be some arbitrary object.
   
   If this sounds vague, its because there is not just one
-  {{{../apidocs/org/apache/tapestry/ioc/ObjectProvider.html}ObjectProvider}}; there's a whole set of them,
+  {{{../apidocs/org/apache/tapestry5/ioc/ObjectProvider.html}ObjectProvider}}; there's a whole set of them,
   forming a {{{command.html}chain of command}}.  The commands in the chain may provide an object
   based on the parameter type, or based on additional annotations on the parameter.
   
   There are two built-in object providers:
   
-  * Check for {{{../apidocs/org/apache/tapestry/ioc/annotations/Value.html}Value}} annotation
+  * Check for {{{../apidocs/org/apache/tapestry5/ioc/annotations/Value.html}Value}} annotation
   
   * Check for a <unique> service in the Registry whose service interface matches the parameter type
   

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/run.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/run.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/run.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/run.apt Tue May 20 11:51:35 2008
@@ -6,7 +6,7 @@
 
  Primarily, you will use the IoC Registry as part of a Tapestry application.
  In those situations, the 
- {{{../apidocs/org/apache/tapestry/TapestryFilter.html}TapestryFilter}} will
+ {{{../apidocs/org/apache/tapestry5/TapestryFilter.html}TapestryFilter}} will
  be responsible for starting and stopping the registry.
  
  However, you may want to do some integration testing using the Registry
@@ -16,7 +16,7 @@
 Building the Registry
 
   The class
-  {{{../apidocs/org/apache/tapestry/ioc/RegistryBuilder.html}RegistryBuilder}}
+  {{{../apidocs/org/apache/tapestry5/ioc/RegistryBuilder.html}RegistryBuilder}}
   is used to create a Registry.
   
 +---+
@@ -34,17 +34,17 @@
   
   Using this approach, you will form a Registry containing
   the builtin services from the
-  {{{../apidocs/org/apache/tapestry/ioc/services/TapestryIoCModule.html}Tapestry IoC module}}, plus
+  {{{../apidocs/org/apache/tapestry5/ioc/services/TapestryIoCModule.html}Tapestry IoC module}}, plus
   the modules you explicitly list.
   
   The call to performRegistryStartup() is necessary to ensure that any services marked with the
-  {{{../apidocs/org/apache/tapestry/ioc/annotations/EagerLoad.html}EagerLoad}} annotation are, in fact,
+  {{{../apidocs/org/apache/tapestry5/ioc/annotations/EagerLoad.html}EagerLoad}} annotation are, in fact,
   loaded.
   
 Building the Default Registry
 
   The default registry is available by invoking the static method
-  {{{../apidocs/org/apache/tapestry/ioc/IOCUtilities.html#buildDefaultRegistry()}IOCUtilities.buildDefaultRegistry()}}.
+  {{{../apidocs/org/apache/tapestry5/ioc/IOCUtilities.html#buildDefaultRegistry()}IOCUtilities.buildDefaultRegistry()}}.
   This method builds a Registry using
   {{{module.html#Autoloading modules}autoloading logic}}, where modules to load
   are identified via a JAR Manifest entry.
@@ -57,7 +57,7 @@
 Shutting down the Registry
 
   The method
-  {{{../apidocs/org/apache/tapestry/ioc/Registry.html#shutdown()}Registry.shutdown()}}
+  {{{../apidocs/org/apache/tapestry5/ioc/Registry.html#shutdown()}Registry.shutdown()}}
   will shutdown the Registry. This immediately invalidates all service proxies.
   Some services may have chosen to register for shutdown notification (for example,
   to do cleanup work such as closing a database connection).

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/service.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/service.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/service.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/service.apt Tue May 20 11:51:35 2008
@@ -77,13 +77,13 @@
   instantiate your services.
 
   Every module may have an optional, static bind() method which is passed a
-  {{{../apidocs/org/apache/tapestry/ioc/ServiceBinder.html}ServiceBinder}}.  Services may be registered with
+  {{{../apidocs/org/apache/tapestry5/ioc/ServiceBinder.html}ServiceBinder}}.  Services may be registered with
   the container by "binding" a service interface to a service implementation:
   
 +------+
 package org.example.myapp.services;
 
-import org.apache.tapestry.ioc.ServiceBinder;
+import org.apache.tapestry5.ioc.ServiceBinder;
 
 public class MyAppModule
 {
@@ -179,7 +179,7 @@
   it down to a <single> service. At this point, it is necessary to <disambiguate> the link between
   the service interface and <one> service.  One approach is to use
   the 
-  {{{../apidocs/org/apache/tapestry/ioc/annotations/InjectService.html}InjectService}} annotation:
+  {{{../apidocs/org/apache/tapestry5/ioc/annotations/InjectService.html}InjectService}} annotation:
   
   
 +-----------------------------------------------------------------------------------+
@@ -278,7 +278,7 @@
   will be able to update all the uses of the annotation or interface.
 
   With a service builder method, you use the
-  {{{../apidocs/org/apache/tapestry/ioc/annotations/Marker.html}@Marker}} annotation:
+  {{{../apidocs/org/apache/tapestry5/ioc/annotations/Marker.html}@Marker}} annotation:
 
 +---+
   @Marker(Clustered.class)
@@ -300,7 +300,7 @@
 +---+
 package org.example.myapp.services;
 
-import org.apache.tapestry.ioc.annotation.InjectService;
+import org.apache.tapestry5.ioc.annotations.InjectService;
 
 public class IndexerImpl implements Indexer
 {
@@ -330,7 +330,7 @@
 +---+
 package org.example.myapp.services;
 
-import org.apache.tapestry.ioc.annotation.InjectService;
+import org.apache.tapestry5.ioc.annotations.InjectService;
 
 public class IndexerImpl implements Indexer
 {
@@ -360,7 +360,7 @@
   more can be added.
   
   Service lifecycle is specified using the 
-  {{{../apidocs/org/apache/tapestry/ioc/annotations/Scope.html}@Scope annotation}},
+  {{{../apidocs/org/apache/tapestry5/ioc/annotations/Scope.html}@Scope annotation}},
   which is attached to a builder method.  When this annotation is not present, the
   default scope, "singleton" is used.
     
@@ -370,7 +370,7 @@
   is created when the service is first referenced.  By reference, we mean any situation in which
   the service is requested by name, such as using the @InjectService annotation on a
   service builder method, or by using the
-  {{{../apidocs/org/apache/tapestry/ioc/Registry.html}Registry}} API from outside the
+  {{{../apidocs/org/apache/tapestry5/ioc/Registry.html}Registry}} API from outside the
   container.
   
   In any case, the service proxy will only create the service implementation when a method
@@ -434,7 +434,7 @@
   Services are normally created only as needed (per the scope discussion above).
   
   This can be tweaked slightly; by adding the 
-  {{{../apidocs/org/apache/tapestry/ioc/annotations/EagerLoad.html}EagerLoad}} annotation to
+  {{{../apidocs/org/apache/tapestry5/ioc/annotations/EagerLoad.html}EagerLoad}} annotation to
   the service builder method, Tapestry will instantiate the service when the Registry is first created.
   
   This will cause the service builder method to be invoked, as well as any service decorator methods.
@@ -475,7 +475,7 @@
   
   * java.lang.Class: service interface implemented by the service to be constructed
   
-  * {{{../apidocs/org/apache/tapestry/ioc/ServiceResources.html}ServiceResources}}:  access to other services
+  * {{{../apidocs/org/apache/tapestry5/ioc/ServiceResources.html}ServiceResources}}:  access to other services
   
   []
   
@@ -553,7 +553,7 @@
 
   It doesn't work because type String always gets the service id, as a resource (as with the serviceId parameter).
   In order to get this to work, we need to turn off the resource injection for the alertEmail parameter.
-  That's what the {{{../apidocs/org/apache/tapestry/ioc/annotations/Inject.html}Inject}} annotation does:
+  That's what the {{{../apidocs/org/apache/tapestry5/ioc/annotations/Inject.html}Inject}} annotation does:
   
 +-----------------------------------------------------------------------------------+
   public static Indexer build(String serviceId, Log serviceLog,  
@@ -577,18 +577,18 @@
   A few services within the Tapestry IOC Module are "builtin"; there is no 
   service builder method
   in the
-  {{{../apidocs/org/apache/tapestry/ioc/services/TapestryIOCModule.html}TapestryIOCModule}} class.
+  {{{../apidocs/org/apache/tapestry5/ioc/services/TapestryIOCModule.html}TapestryIOCModule}} class.
   
 *---------------------+-----------------------------------------------------------------------------------------+
 | <<Service Id>>      | <<Service Interface>>                                                                   |
 *---------------------+-----------------------------------------------------------------------------------------+
-| ClassFactory        | {{{../apidocs/org/apache/tapestry/ioc/services/ClassFactory.html}ClassFactory}}         |
+| ClassFactory        | {{{../apidocs/org/apache/tapestry5/ioc/services/ClassFactory.html}ClassFactory}}         |
 *---------------------+-----------------------------------------------------------------------------------------+
-| LoggerSource        | {{{../apidocs/org/apache/tapestry/ioc/LoggerSource.html}LoggerSource}}                  |
+| LoggerSource        | {{{../apidocs/org/apache/tapestry5/ioc/LoggerSource.html}LoggerSource}}                  |
 *---------------------+-----------------------------------------------------------------------------------------+
-| RegistryShutdownHub | {{{../apidocs/org/apache/tapestry/ioc/RegistryShutdownHub.html}RegistryShutdownHub}}    |
+| RegistryShutdownHub | {{{../apidocs/org/apache/tapestry5/ioc/RegistryShutdownHub.html}RegistryShutdownHub}}    |
 *---------------------+-----------------------------------------------------------------------------------------+
-| PerthreadManager    | {{{../apidocs/org/apache/tapestry/ioc/services/PerthreadManager.html}PerthreadManager}} |
+| PerthreadManager    | {{{../apidocs/org/apache/tapestry5/ioc/services/PerthreadManager.html}PerthreadManager}} |
 *---------------------+-----------------------------------------------------------------------------------------+
 
   Consult the JavaDoc for each of these services to identify under what circumstances you'll need to use them.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/shadow.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/shadow.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/shadow.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/shadow.apt Tue May 20 11:51:35 2008
@@ -5,7 +5,7 @@
 Shadow Services
 
   The 
-  {{{../apidocs/org/apache/tapestry/ioc/services/PropertyShadowBuilder.html}PropertyShadowBuilder}}
+  {{{../apidocs/org/apache/tapestry5/ioc/services/PropertyShadowBuilder.html}PropertyShadowBuilder}}
   service is used to build a special, delegating kind of service implementation.
   
   Effectively, it is used to allow a property of another service to be exposed as its own service.
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/RegistryShutdownHub.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/RegistryShutdownHub.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
 /**
  * Event hub for notifications when the IOC {@link org.apache.tapestry.ioc.Registry} shuts down.
  */
 public interface RegistryShutdownHub
 {
@@ -12,10 +12,10 @@
 
 /**
- * Event hub for notifications when the IOC {@link org.apache.tapestry.ioc.Registry} shuts down.
+ * Event hub for notifications when the IOC {@link org.apache.tapestry5.ioc.Registry} shuts down.
  */
 public interface RegistryShutdownHub

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/RegistryShutdownListener.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/RegistryShutdownListener.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ServiceActivityScoreboard.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ServiceActivityScoreboard.java Tue May 20 11:51:35 2008
@@ -12,13 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
 import java.util.List;
 
 /**
  * Provides access to the runtime details about services in the
  * {@link org.apache.tapestry.ioc.Registry}.
  */
 public interface ServiceActivityScoreboard
 {
@@ -12,13 +12,12 @@
 
 /**
- * Provides access to the runtime details about services in the
- * {@link org.apache.tapestry.ioc.Registry}.
+ * Provides access to the runtime details about services in the {@link org.apache.tapestry5.ioc.Registry}.
  */
 public interface ServiceActivityScoreboard

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ServiceLifecycleSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ServiceLifecycleSource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/TapestryIOCModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/TapestryIOCModule.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import org.apache.tapestry.ioc.*;
-import static org.apache.tapestry.ioc.IOCConstants.PERTHREAD_SCOPE;
-import org.apache.tapestry.ioc.annotation.Marker;
-import org.apache.tapestry.ioc.annotation.Value;
-import org.apache.tapestry.ioc.internal.services.*;
-import org.apache.tapestry.ioc.util.TimeInterval;
+import org.apache.tapestry5.ioc.*;
+import static org.apache.tapestry5.ioc.IOCConstants.PERTHREAD_SCOPE;
+import org.apache.tapestry5.ioc.annotations.Marker;
+import org.apache.tapestry5.ioc.annotations.Value;
+import org.apache.tapestry5.ioc.internal.services.*;
+import org.apache.tapestry5.ioc.util.TimeInterval;
 
 import java.io.File;
 import java.lang.reflect.Array;
@@ -104,7 +104,7 @@
      * strings are true)</li> <li>Long to Boolean (true if long value is non zero)</li> <li>Null to Boolean (always
      * false)</li> <li>Collection to Boolean (false if empty)</li> <li>Object[] to List</li> <li>primitive[] to
      * List</li> <li>Object to List (by wrapping as a singleton list)</li>  <li>String to File</li> <li>String to {@link
      * org.apache.tapestry.ioc.util.TimeInterval}</li> <li>{@link org.apache.tapestry.ioc.util.TimeInterval} to
      * Long</li> </ul>
      */
     @SuppressWarnings("unchecked")
@@ -104,7 +104,7 @@
      * false)</li> <li>Collection to Boolean (false if empty)</li> <li>Object[] to List</li> <li>primitive[] to
      * List</li> <li>Object to List (by wrapping as a singleton list)</li>  <li>String to File</li> <li>String to {@link
-     * org.apache.tapestry.ioc.util.TimeInterval}</li> <li>{@link org.apache.tapestry.ioc.util.TimeInterval} to
+     * org.apache.tapestry5.ioc.util.TimeInterval}</li> <li>{@link org.apache.tapestry5.ioc.util.TimeInterval} to
      * Long</li> </ul>
      */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ThreadCleanupListener.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ThreadCleanupListener.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/BodyBuilder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/BodyBuilder.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.util;
+package org.apache.tapestry5.ioc.util;
 
-import org.apache.tapestry.ioc.services.MethodSignature;
+import org.apache.tapestry5.ioc.services.MethodSignature;
 
 import java.util.Formatter;
 
@@ -152,8 +152,8 @@
 
     /**
      * Returns the current contents of the buffer. This value is often passed to methods such as {@link
      * org.apache.tapestry.ioc.services.ClassFab#addConstructor(Class[], Class[], String)} or {@link
      * org.apache.tapestry.ioc.services.ClassFab#addMethod(int, MethodSignature, String)}.
      * <p/>
      * A BodyBuilder can be used again after invoking toString(), typically by invoking {@link #clear()}.
      */
@@ -162,4 +162,4 @@
     {
         return buffer.toString();
     }
-}
\ No newline at end of file
+}
@@ -152,8 +152,8 @@
     /**
      * Returns the current contents of the buffer. This value is often passed to methods such as {@link
-     * org.apache.tapestry.ioc.services.ClassFab#addConstructor(Class[], Class[], String)} or {@link
-     * org.apache.tapestry.ioc.services.ClassFab#addMethod(int, MethodSignature, String)}.
+     * org.apache.tapestry5.ioc.services.ClassFab#addConstructor(Class[], Class[], String)} or {@link
+     * org.apache.tapestry5.ioc.services.ClassFab#addMethod(int, MethodSignature, String)}.
      * <p/>
      * A BodyBuilder can be used again after invoking toString(), typically by invoking {@link #clear()}.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/CaseInsensitiveMap.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/util/CaseInsensitiveMap.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================